// Marta Fernandez Poyatos


// Función que crea el gráfico de barras agrupadas
function update (InputFileName){
 //svg.selectAll("g").remove();
  d3.select('#graf').selectAll('svg').remove();

 // Dimensiones y margenes del grafico de barras
  var margin = {top: 100, right: 0, bottom: 170, left: 70},
  width = 890 - margin.left - margin.right,
  height = 660 - margin.top - margin.bottom;


  // Creamos el objeto svg en el espacio graf donde dibujaremos el grafico
  var svg = d3.select('#graf')
    .append("svg")
    .attr("width", width + margin.left + margin.right)
    .attr("height", height + margin.top + margin.bottom)
    .append("g")
    .attr("transform", "translate(" + margin.left + "," + margin.top + ")");

  //Título
  var titulo = svg.append("text")
    .attr("x", width/2 )
    .attr("y", margin.top-160)
    .attr("text-anchor", "middle")
    .style("font-size", "25px")
    .style("font-weight", "bold")
    .attr("font-family", "sans-serif")
    .text("Encuesta sobre enfermedades mentales");


  // Etiqueta que muestra el numero de personas que padece cada enfermedad
  var tooltip = d3.select("body")
    .append("div")
    .attr("class", "tooltip")
    .style("opacity",0)
    .style("border", "solid")
    .style("border-width", "2px")
    .style("border-radius", "5px")

  
  // Cargamos los datos
  d3.csv(InputFileName, function(error,data) {

    if(error)throw error;

    //Lista de los subgrupos 
    var subgroups = data.columns.slice(1)

    
    // Lista de los grupos 
    var groups = d3.map(data, function(d){return(d.Enfermedades)}).keys()


    // Añadir eje x
    var x = d3.scaleBand()
      .domain(groups)
      .range([0, width])
      .padding([0.2])
    svg.append("g")
      .attr("transform", "translate(0," + height + ")")
      .call(d3.axisBottom(x).tickSize(10))
      .selectAll("text")
      .attr("transform", "translate(-10,10)rotate(-45)")
      .style("text-anchor", "end")
      .style("font-family", "sans-serif")
      .style("font-size", "15px");

    // Añadir eje y
    var y = d3.scaleLinear()
      .domain([0, 20])
      .range([ height, 0 ]);
    svg.append("g")
      .call(d3.axisLeft(y));

    // Otra escala para los subgrupos
    var xSubgroup = d3.scaleBand()
      .domain(subgroups)
      .range([0, x.bandwidth()])
      .padding([0.05])

    // Definimos los colores de las barras
    var color = d3.scaleOrdinal()
      .domain(subgroups)
      .range(['#149BB3','#091277','#E260CE','#7F0664'])


    // Etiquetas del eje y
    svg.append("text")
        .attr("text-anchor", "end")
        .attr("transform", "rotate(-90)")
        .attr("y", -margin.left+25)
        .attr("x", -margin.top+80)
        .text("Número de personas")
        .selectAll("text")
        .style("font-size", '42px');
      

    // Añadimos el grid del eje y
    svg.append("g")
      .attr("class", "grid")
      .call(d3.axisLeft(y)
        .tickSize(-width)
        .tickFormat("")
      )
      .style("opacity", 0.2);  

      // Definimos las funciones que reciben el evento del movimiento del ratón
        var mouseover = function(d) {
           d3.select(this)
           .style("stroke", "black")
           .style("opacity", 0.4);
           d3.selectAll(".bar").transition().duration(40).style("opacity",0.5);
           d3.selectAll("#"+d3.select(this).attr("id")).transition().duration(1)
           .style("opacity", 1)
           .attr("y",function(d){return y(d.Enfermedades);})
           .attr("height",21);
   
           tooltip.transition()
           .duration(300)
           .style("opacity", 1);
        }
        var mousemove = function(d) {

         tooltip.selectAll("text").remove();
         tooltip.selectAll("br").remove();
         tooltip.style("left", (d3.event.pageX ) + "px")
         .style("top", (d3.event.pageY) + "px")
        	tooltip.append("text").text("Nº de personas: "+(d.value));
        }
        
        var mouseleave = function(d) {
          tooltip
            .style("opacity", 0)
          d3.select(this)
            .style("stroke", "none")
            .style("opacity", 0.8)
      
        }

     

    ////////////// Dibujo grouped barplot ///////////////
  
    // Mostramos las barras
      svg.append("g")
        .selectAll("g")
        // Introducimos los datos
        .data(data)
        .enter()
        .append("g")
        .attr("transform", function(d) { return "translate(" + x(d.Enfermedades) + ",0)"; })
        .selectAll("rect")
        .data(function(d) { return subgroups.map(function(subgroups) { return {subgroups: subgroups, value: d[subgroups]}; }); })
        .enter().append("rect")
        .on("mouseover", mouseover)//capturamos el movimiento del raton 
        .on("mousemove", mousemove)
        .on("mouseleave", mouseleave)//capturamos la salida del raton
        
        .attr("x", function(d) { return xSubgroup(d.subgroups); })
        .attr("y", function(d) { return y(d.value); })
        .transition() //introducimos los rectangulos de forma dinamica
        .duration(1000)//tiempo que dura la transicion
        .delay(function(d,i){ return(i*100)})
        .attr("y", function(d) { return y(d.value); })
        .attr("width", xSubgroup.bandwidth())
        .attr("height", function(d) { return height - y(d.value); })
        .attr("fill", function(d) { return color(d.subgroups); });
      
  })


}

// Función que crea el gráfico de barras apiladas
function stacked(InputFileName){
    //svg.selectAll("g").remove();
    d3.select('#graf').selectAll('svg').remove();
    // Dimensiones y margenes del grafico de barras
  var margin = {top: 100, right: 0, bottom: 170, left: 70},
  width = 890 - margin.left - margin.right,
  height = 660 - margin.top - margin.bottom;


  // Creamos el objeto svg en el espacio graf donde dibujaremos el grafico
  var svg = d3.select('#graf')
    .append("svg")
    .attr("width", width + margin.left + margin.right)
    .attr("height", height + margin.top + margin.bottom)
    .append("g")
    .attr("transform", "translate(" + margin.left + "," + margin.top + ")");

  //Título
  var titulo = svg.append("text")
    .attr("x", width/2 )
    .attr("y", margin.top-160)
    .attr("text-anchor", "middle")
    .style("font-size", "25px")
    .style("font-weight", "bold")
    .attr("font-family", "sans-serif")
    .text("Encuesta sobre enfermedades mentales");

  // Etiqueta que muestra el numero de personas que padece cada enfermedad
  var tooltip = d3.select("body")
    .append("div")
    .attr("class", "tooltip")
    .style("opacity",0)
    .style("border", "solid")
    .style("border-width", "2px")
    .style("border-radius", "5px")

  d3.csv(InputFileName, function(data) {

    // Lista de subgrupos
    var subgroups = data.columns.slice(1)

    // Lista de grupos
    var groups = d3.map(data, function(d){return(d.Enfermedades)}).keys()

    // Añadir eje x
    var x = d3.scaleBand()
      .domain(groups)
      .range([0, width])
      .padding([0.2]);
    svg.append("g")
      .attr("transform", "translate(0," + height + ")")
      .call(d3.axisBottom(x).tickSizeOuter(0))
      .selectAll("text")
      .attr("transform", "translate(-10,10)rotate(-45)")
      .style("text-anchor", "end")
      .style("font-family", "sans-serif")
      .style("font-size", "15px");


    // Añadir eje y
    var y = d3.scaleLinear()
      .domain([0, 60])
      .range([ height, 0 ]);
    svg.append("g")
      .call(d3.axisLeft(y));

      // Dibujar grid del eje y
      svg.append("g")
        .attr("class", "grid")
        .call(d3.axisLeft(y)
          .tickSize(-width)
          .tickFormat("")
        )
        .style("opacity", 0.2);  ; 

    // Color de las barras
    var color = d3.scaleOrdinal()
      .domain(subgroups)
      .range(['#149BB3','#091277','#E260CE','#7F0664'])

    // Definimos las funciones que reciben el evento del movimiento del ratón  
    var mouseover = function(d) {
     
       d3.select(this)
       .style("stroke", "black")
       .style("opacity", 0.4);
       d3.selectAll(".bar").transition().duration(40).style("opacity",0.5);
       d3.selectAll("#"+d3.select(this).attr("id")).transition().duration(1)
       .style("opacity", 1)
       .attr("y",function(d){return y(d.Enfermedades);})
       .attr("height",21);

       tooltip.transition()
       .duration(300)
       .style("opacity", 1);
    }

    var mousemove = function(d) {

      tooltip.selectAll("text").remove();
      tooltip.selectAll("br").remove();
      tooltip.style("left", (d3.event.pageX ) + "px")
      .style("top", (d3.event.pageY) + "px")
      tooltip.append("text").text("Nº de personas: "+(d[1]-(d[0])));
    }

    var mouseleave = function(d) {
      tooltip
        .style("opacity", 0)
      d3.select(this)
        .style("stroke", "none")
        .style("opacity", 0.8)
    }

  ////////// Dibujo stacked barplot ////////////   

  //Apilamos los datos por subgrupos
  var stackedData = d3.stack()
    .keys(subgroups)
    (data)

  // Mostrar las barras
  svg.append("g")
    .selectAll("g")
    // Introducir los datos
    .data(stackedData)
    .enter().append("g")
    .attr("fill", function(d) { return color(d.key); })
    .selectAll("rect")
    .data(function(d) { return d; })
    .enter().append("rect")
    .on("mouseover", mouseover)//capturamos el movimiento del raton
    .on("mousemove", mousemove)
    .on("mouseleave", mouseleave)//capturamos la salida del raton
        
    .attr("x", function(d) { return x(d.data.Enfermedades); })
    .attr("y", function(d) { return y(d[1]); }) 
    .transition() //introducimos los rectangulos de forma dinamica
    .duration(1000)//tiempo que dura la transicion
    .delay(function(d,i){ return(i*100)})
    .attr("height", function(d) { return y(d[0]) - y(d[1]); })
    .attr("width",x.bandwidth())
        
})
}


////////// Escribimos la leyenda //////////////
   var legend = d3.select("#leyenda").append('svg')
      .attr("width",450)
      .attr("height",150)
      .append("g");
   //Rectangulos identificativos
   legend.append("rect")
      .attr("x",15)
      .attr("y",30)
      .attr("height",20)
      .attr("width",20)
      .attr("fill","#149BB3");
     legend.append('rect')
      .attr("x",15)
      .attr("y",60)
      .attr("height",20)
      .attr("width",20)
      .attr("fill","#091277");
     legend.append("rect")
      .attr("x",15)
      .attr("y",90)
      .attr("height",20)
      .attr("width",20)
      .attr("fill","#E260CE");
     legend.append('rect')
      .attr("x",15)
      .attr("y",120)
      .attr("height",20)
      .attr("width",20)
      .attr("fill","#7F0664");

   //Informacion para cada rectangulo
   legend.append("text")
      .attr("x",45)
      .attr("y",45)
      .attr("font-family", "sans-serif")
      .style("font-size", "15px")
      .text("Hombres trabajadores");
    legend.append("text")
      .attr("x",45)
      .attr("y",75)
      .attr("font-family", "sans-serif")
      .style("font-size", "15px")
      .text("Hombres en paro");
    legend.append("text")
      .attr("x",45)
      .attr("y",105)
      .attr("font-family", "sans-serif")
      .style("font-size", "15px")
      .text("Mujeres trabajadoras");
    legend.append("text")
      .attr("x",45)
      .attr("y",135)
      .attr("font-family", "sans-serif")
      .style("font-size", "15px")
      .text("Mujeres en paro");

     legend.append("text")
      .attr("x",15)
      .attr("y",10)
      .attr("font-family", "sans-serif")
      .style("font-weight", "bold")
      .style("font-size", "15px")
      .text("Leyenda");



      



